import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.BorderLayout;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Ein Fenster zum Darstellen eines Bildes.
 * 
 * @author Bernd Gramlich 
 * @version 2013-05-01
 */
public class Bildfenster implements ActionListener
{
    private JFrame fenster;
    private JPanel fensterraum;
    private JLabel bildflaeche;
    private JButton schliessenknopf;
    private JFrame elternfenster;
    private WindowAdapter fensterBeobachter;

    /**
     * Konstruktor
     */
    public Bildfenster (JFrame elter, String fenstername, String bildname)
    {
        elternfenster = elter;
        elternfenster.disable ();
        
        URL bildquelle = getClass ().getClassLoader ().getResource (bildname);
        
        if (null != bildquelle)
        {
            bildflaeche = new JLabel (new ImageIcon (bildquelle));
        }
        
        schliessenknopf = new JButton ("Schliessen");
        schliessenknopf.addActionListener (this);
        
        fensterraum = new JPanel ();
        if (null != bildflaeche)
        {
            fensterraum.add (bildflaeche, BorderLayout.PAGE_START);
        }
        fensterraum.add (schliessenknopf, BorderLayout.PAGE_END);
        
        fenster = new JFrame (fenstername);
        fenster.setDefaultCloseOperation (JFrame.DO_NOTHING_ON_CLOSE);
        fenster.addWindowListener (new fensterHorcher ());
        fenster.getContentPane ().add (fensterraum);
        fenster.pack ();
        fenster.setLocationRelativeTo (null);
        fenster.setVisible (true);
    }
    
    /**
     * Reagiere auf Benutzeraktionen.
     */
    public void actionPerformed (ActionEvent ereignis)
    {
        if (ereignis.getSource () == schliessenknopf)
        {
            fenster.dispose ();
            elternfenster.enable ();
            elternfenster.toFront ();
            elternfenster.repaint ();
        }
    }
    
    /**
     * Die Klasse fensterHorcher dient dazu, dass das Fenster sich beim
     * Schliessen vom Betriebssystem her genauso verhaelt wie beim Druecken
     * des Schliessenknopfs.
     */
    private class fensterHorcher extends WindowAdapter
    {
        public void windowClosing (WindowEvent fensterereignis)
        {
           if (fensterereignis.getWindow () == fenster)
           {
               schliessenknopf.doClick ();
           }
        }
    }
}
